function [S,knots] = BScurve(b,k,t,knots)
%
% same as BScurve3
%
% S = BScurve(b,k,t)
% [S,knots] = BScurve(b,k,t,knots)
%
% B-spline curve with control points b of order k evaluated at t
n = size(b,2)-1;
if (nargin == 3)
  knots = linspace(0,1,n+1-k+2);
  knots = [zeros(1,k-1),knots,ones(1,k-1)];
end
B = BSplineEval(k,knots,t);
S = b*cat(1,B{:});
%!demo
%! t = linspace(0,1,51);
%! b = [0,0,1,1,1/2,1/2;0,1,1,0,0,1/2];
%! n = size(b,2)-1;
%! for k = 1:n+1
%!   s{k} = BScurve3(b,k,t);
%! end
%! y = decasteljau(b,t);
%! plot(b(1,:),b(2,:),'o',s{1}(1,:),s{1}(2,:),'*',
%!      s{2}(1,:),s{2}(2,:),s{3}(1,:),s{3}(2,:),s{4}(1,:),s{4}(2,:),...
%!      s{5}(1,:),s{5}(2,:),s{6}(1,:),s{6}(2,:),...
%!      y{1}(1,:),y{1}(2,:),'x')
%! axis([-1,2,-1,2])
%! legend('control points','B-spline curve order 1','B-spline curve order 2','B-spline curve order 3','B-spline curve order 4','B-spline curve order 5','B-spline curve order 6','Bezier curve')